// ************************************************************
// Persistence Of Vision Ray Tracer Scene Description File
// File name  : demo_despertador.pov
// Version    : 3.6.1
// Description: alarm-clock demo scene
// Date       : Jun 2006
// Author     : Jaime Vives Piqueres
// ************************************************************
// aspect ratio 3/4 (i.e. 240x320)

// standard includes
#include "colors.inc"
#include "textures.inc"
#include "metals.inc"
#include "glass.inc"
#include "benediti.map"

// *** globals ***
#declare use_blur    =7*0;  // blur samples (0=off)
global_settings{
 max_trace_level 7
// radiosity{}
}
#default{texture{finish{ambient 0}}}

// *** simple room & stand ***
box{-.5,.5 scale <500,250,500>
 pigment{brick scale 4} 
 translate 125*y
}
box{-.5,.5 scale <80,80,80>
 pigment{granite color_map{M_Benediti} scale 2}
 translate 40*y
}

// *** demo clock textures ***
#declare t_glass=
texture{T_Glass3 pigment{rgbt .99}
}
#declare t_black_plastic=
texture{
 pigment{Gray10} 
 finish{reflection{0,.33}}
}
#declare t_green_plastic=
texture{
 pigment{White*.75+Green*.33} 
 finish{ambient Green*.1}
}
#declare t_red_plastic=
texture{
 pigment{OrangeRed} 
 finish{reflection{0,.33}} 
 normal{onion 1 scale .25}
}
#declare t_metal=
texture{
 pigment{White}
 finish{reflection {.9,1} diffuse .1}
}
#declare t_clock_case=t_metal
#declare t_clock_face=
texture{
 pigment{
  image_map{jpeg "clockface2"} translate -.5 scale 1.6 
 }
 finish{
  reflection {.01,.1} 
 }
}

// *** test alarm clock macro ***
#declare use_clock_glass=1;
#include "despertador.inc"
// use random time setting:
#declare r_time=seed(67); // seend for random time
object{alarm_clock(
  <int(12*rand(r_time)),int(60*rand(r_time)),int(60*rand(r_time))>, // time to display
  <int(12*rand(r_time)),int(60*rand(r_time)),int(60*rand(r_time))>  // alarm time
 )
 translate 80*y
}
// or use specific times:
//object{alarm_clock(<10,10,30>,<7,30,0>) translate 80*y}

// *** camera ***
#declare cl=<10,25*.75,-88*.75>;
#declare la=<0,14,0>;
camera{
 location cl
 up 3.2*y right 2.4*x
 direction 5*z
 look_at la
 #if (use_blur)
 focal_point la
 aperture pi/2
 blur_samples use_blur
 variance 0
 #end
 translate 80*y
}

// *** quick lighting ***
light_source{
 <-150,245,-200>,White+Turquoise
 spotlight radius 15 falloff 45 point_at 80*y
 looks_like{
  sphere{0,100 no_shadow pigment{White} finish{ambient White+Turquoise}}
 }
}

