// ************************************************************
// Persistence Of Vision Ray Tracer Scene Description File
// File name  : despertador.inc
// Version    : 3.6.1
// Description: alarm-clock main include
// Date       : Jun 2006
// Author     : Jaime Vives Piqueres
// ************************************************************

// arrow shape macro
#macro saeta_shape(s_long,s_rad)
intersection{
 union{
  cylinder{0,y*s_long,s_rad} 
  sphere{0,s_rad}
  sphere{y*s_long,s_rad}
 }
 plane{z,s_rad*.25}
 plane{z,-s_rad*.25 inverse}
}
#end

// build the arrows
#declare saeta_h= // hour
union{
 object{saeta_shape(3.5,.4) texture{t_black_plastic}}
 object{saeta_shape(1,.25) texture{t_green_plastic}
  translate <0,2.5,.05>
 }
}
#declare saeta_m= // min.
union{
 object{saeta_shape(5,.3) texture{t_black_plastic}}
 object{saeta_shape(2,.2) texture{t_green_plastic}
  translate <0,3,.05>
 }
}
#declare saeta_s= // sec.
union{
 object{saeta_shape(7,.1) translate -1.5*y}
 cylinder{-.05*z,.05*z,.6}
 texture{t_red_plastic}
}
#declare saeta_a= // alarm
object{saeta_shape(4.1,.1) 
 texture{t_metal}
}

// *** build the alarm clock ***
#include "despertador_mesh.inc"
// macro params: time (<hour(0-12), minutes, seconds>), alarm (idem)
#macro alarm_clock(ac_time,ac_alarm)
union{
 // case mesh
 object{despertador scale <-1,1,1>*9}
 // front glass
 #if (use_clock_glass)
 intersection{
  sphere{0,1.673*.5*9 scale <1,1,.33>}
  plane{z,0 inverse}
  texture{t_glass scale 9}
  translate 1*z
 }
 #end
 // arrows
 union{
  // hour arrow
  object{saeta_h rotate (ac_time.x*(360/12)+(ac_time.y/60)*(360/12))*z translate .22*z} 
  // minutes arrow
  object{saeta_m rotate ac_time.y*(360/60)*z translate .23*z}
  // seconds arrow
  object{saeta_s rotate ac_time.z*(360/60)*z translate .3*z}
  // alarm arrow
  object{saeta_a rotate (ac_alarm.x*(360/12)+(ac_alarm.y/60)*(360/12))*z translate .21*z} 
  translate <0,0,.9>
 }
 rotate 180*y
 translate 11.5*y
}
#end


